%This function executes any time a motor performs a scan
%It is called from the function startScan and facilitates communication between 
%Matlab and the Arduino during scans
%Inputs:
%side - char - "R" or "L" indicating the currently selected side
%axis - char - "X" or "Y" indicating the currently selected axis
%s - double - the handle of the currently open serial object
%start - double - the angle at which to start the scan
%finish - double - the angle at which to stop the scan
%dir - double - +1 or -1 indicating the direction to step during the scan
%statusBox - the handle of a box in the display window which displays 
%the current position of the scanning servo
%Outputs:
%angle - double - the angle at which the scan was stopped

function angle  = MotorMove( side,axis,s,start,finish,dir,statusBox )
 
 

if side == 'Z'
	%No side selected
    errordlg('Please select a side')
elseif axis == 'Z'
	%no axis selected
    errordlg('Please Select an Axis')
else
    %Initialize angle to the last position of the scan in case the button isn't pressed
   angle=finish; 

    for i = start:dir:finish
		%Flush Buffers
        handshake='k';
        flushinput(s);
        flushoutput(s);
        
        %Generate 5 char command to move servo
        if i<10
            n = ['.' side axis '00' int2str(i)];
        elseif i<100
            n = ['.' side axis '0' int2str(i)];
        else
            n = ['.' side axis int2str(i)];
        end

        %write command to Arduino
        fwrite(s,n);
        pause(.25)

        %Wait for Arduino to be ready for next command (receive ready char) 
        while handshake == 'k'
            handshake = fgetl(s);
            if (handshake ~='r') && (handshake ~= 'b')
                handshake = 'k';
            end
        end
        set(statusBox,'string',num2str(i));
        
       if handshake == 'r'
	   %Arduino Ready
            fgetl(s);
       end
        
        if handshake == 'b'
            %Button pressed, interrupt loop, save position to output variable
            angle = str2double(fgetl(s));
            handshake = 'k';
            break
        end
    end
    
	%flush buffers
    flushinput(s);
    flushoutput(s);
    
    

end
end

