%This function executes when the "Plot Visual Field" button is pressed in the 
%control window (after the display window has been opened), or when the 
%"Load Data to Plot" button is pressed in the display window after the file containing the 
%data has been selected
%It plots the currently selected data set in the display window
%Inputs: 
%angleData - matrix double (4,2) - The currently loaded data from perimeter mode
%blindSpotData - matrix double (4,2) - The currently loaded data from perimeter mode
%Outputs:
%RP - double - handle of the right eye perimeter mode ellipse
%RB - double - handle of the right eye blind spot mode ellipse
%LP - double - handle of the left eye perimeter mode ellipse
%LB - double - handle of the left eye blind spot mode ellipse

function [RP RB LP LB] = createPlot(angleData,blindSpotData)

%For each eye and mode, calculate the coordinates of the center of the ellipse
%and the lengths of the major and minor axes

%Right Eye
%Perimiter mode
xc_RP  = (angleData(1,2) - angleData(2,2))/2 + angleData(2,2);
yc_RP = (angleData(3,2) + angleData(4,2))/2 - 70;
r1_RP = (angleData(1,2) - angleData(2,2))/2;
r2_RP = (angleData(3,2) - angleData(4,2))/2;

%Blindspot mode
xc_RB = (blindSpotData(2,2) - blindSpotData(1,2))/2 + blindSpotData(1,2);
yc_RB = (blindSpotData(4,2) + blindSpotData(3,2))/2 - 70;
r1_RB = (blindSpotData(2,2) - blindSpotData(1,2))/2;
r2_RB = (blindSpotData(4,2) - blindSpotData(3,2))/2;

%Left Eye
%Perimiter mode
xc_LP  = -((angleData(1,1) - angleData(2,1))/2 + angleData(2,1));
yc_LP = (angleData(3,1) + angleData(4,1))/2 - 75;
r1_LP = (angleData(1,1) - angleData(2,1))/2;
r2_LP = (angleData(3,1) - angleData(4,1))/2;

%Blindspot mode
xc_LB = -((blindSpotData(2,1) - blindSpotData(1,1))/2 + blindSpotData(1,2));
yc_LB = (blindSpotData(4,1) + blindSpotData(3,1))/2 - 75;
r1_LB = (blindSpotData(2,1) - blindSpotData(1,1))/2;
r2_LB = (blindSpotData(4,1) - blindSpotData(3,1))/2;


%Plot all 4 ellipses
RP = ellipse(r1_RP,r2_RP,0,xc_RP,yc_RP);
RB = ellipse(r1_RB,r2_RB,0,xc_RB,yc_RB);
LP = ellipse(r1_LP,r2_LP,0,xc_LP,yc_LP);
LB = ellipse(r1_LB,r2_LB,0,xc_LB,yc_LB);