%This function executes when the "Load Data to Plot" button is pressed in the display window
%It allows the user to select a .txt file containing previously recorded data and plots it in 
%the display window
%Inputs:
%numDataSets - double - the number of data sets currently visible in the display window
%blinkRates - 1D double array - The blink rate associated with each data set currently visible in the display window
%h4legend - 1D double array - The handle of the RP ellipse for each data set used to update the legend
%Outputs:
%blinkRates - 1D double array - updated to include newly added data
%h4legend - 1D double array - updated to include newly added data
%RP - double - handle of the right eye perimeter mode ellipse of the newest data
%RB - double - handle of the right eye blind spot mode ellipse of the newest data
%LP - double - handle of the left eye perimeter mode ellipse of the newest data
%LB - double - handle of the left eye blind spot mode ellipse of the newest data

function [blinkRates h4legend RP RB LP LB] = load2plot(numDataSets,blinkRates,h4legend)

%Open a dialog box for the user to choose the .txt file to load
[FileName,PathName] = uigetfile('*.txt','Select the Perimietry Data File');
file = [PathName FileName ];
fopen(file);

%read data from the file
data = textread(file,'%d');

%Create array of data for each mode
blinkRates = [blinkRates data(1)];
angleData = [data(2:3)'; data(4:5)'; data(6:7)'; data(8:9)'];
blindSpotData = [data(10:11)'; data(12:13)'; data(14:15)'; data(16:17)'];

%Plot new data in display window
[RP RB LP LB] = createPlot(angleData,blindSpotData);

%Update list of handles for legend
h4legend = [h4legend RP];

%Change the color of the data to differentiate between different data sets
%There are 6 color choices, so one out of every 6 data sets will be the same color

color = rem(numDataSets,6);
if color == 0
    color = [0 0 1];
elseif color == 1
    color = [0 0 0];
elseif color == 2
    color = [.749 0 .749];
elseif color == 3
    color = [0 1 0];
elseif color == 4
    color = [1 0 0];
else 
    color = [0 .5 .5];
end

set(RP,'Color',color)
set(LP,'Color',color)
set(RB,'Color',color)
set(LB,'Color',color)

%Label the data with the blink rate in the legend
brStr = cell(1,length(blinkRates));

for i = 1:length(blinkRates)
    brStr{i} = num2str(blinkRates(i));
end


legend('off')
legend(h4legend,brStr,'location','East')
    