%This function executes when the "Load Previous Data" button is pressed in the controls window
%It reads previously collected data from a user-selected .txt file and displays it in the tables 
%in the controls window
%Inputs:
%table1 - double - handle of the table for perimeter mode data
%table2 - double - handle of the table for blind spot mode data
%blink_box - double - handle of the text box containing the blink rate
%Outputs:
%bRate - blink rate at which this data was taken
%angleData - matrix double (4,2) - loaded perimeter mode data
%blindSpotData - matrix double (2,4) - loaded blind spot mode data
function [bRate angleData blindSpotData] = loadMyData(table1,table2,blink_box)

%Open dialog box for user to select which file to load
[FileName,PathName] = uigetfile('*.txt','Select the Perimietry Data File');
file = [PathName FileName ];
fopen(file);

%Read data from file
data = textread(file,'%d');

%Store data in output variables
bRate = data(1);
angleData = [data(2:3)'; data(4:5)'; data(6:7)'; data(8:9)'];
blindSpotData = [data(10:11)'; data(12:13)'; data(14:15)'; data(16:17)'];

%Update tables, text box displaying blink rate
set(table1,'data',angleData);
set(table2,'data',blindSpotData);
set(blink_box,'string',int2str(bRate));


