%This function executes when the "Start Scan" button is pressed in the control window
%It specifies some parameters, then calls the function motorMove to perform the scans
%Inputs:
%mode - char - "P" or "B" for perimeter mode or blind spot mode
%side - char - "L" or "R" indicating the currently selected side
%axis - char - "X" or "Y" indicating the currently selected axis
%s - double - the handle of the currently open serial object
%direction - char - "P" or "N" indicating whether the scan goes 
%in the positive or negative direction along the axis
%angleData - matrix double (4,2) - currently valid perimeter mode data
%table1 - double - handle of table to display perimeter mode data
%blindSpotData - matrix double (4,2) - currently valid blind spot mode data
%table2 - double - handle of table to display blind spot mode data
%statusBox - handle of text box which displays the current position of the motor during scans
%Outputs:
%angleData - matrix double (4,2) - updated perimeter mode data
%blindSpotData - matrix double (4,2) - updated blind spot mode data

function [angleData blindSpotData] = startScan(mode,side,axis,s,direction,angleData,table1,blindSpotData,table2,statusBox)


if side == 'Z'
	%Side not selected
    errordlg('Please select a side')
elseif axis == 'Z'
	%axis not selected
    errordlg('Please Select an axis')
else
    if side == 'R'
		%populate column 2 of table for right side data
        col = 2;
        
		%Move left laser directly on front of right eye
        fwrite(s,'.LX063')
        %Wait for Arduino to be ready for next command
        handshake = 'k';
        while handshake == 'k'
            handshake = fgetl(s);
            if handshake ~='r' && handshake ~= 'b'
                handshake = 'k';
            else
                fgetl(s);
            end
        end
        
        fwrite(s,'.LY075')
        %Wait for Arduino to be ready for next command
        handshake = 'k';
        while handshake == 'k'
            handshake = fgetl(s);
            if handshake ~='r' && handshake ~= 'b'
                handshake = 'k';
            else
                fgetl(s);
            end
        end
        
    else
		%populate column 1 of table for left side data
        col = 1;
        
		%Move right laser to directly in front of left eye
         fwrite(s,'.RX070')
        %Wait for Arduino to be ready for next command
        handshake = 'k';
        while handshake == 'k'
            handshake = fgetl(s);
            if handshake ~='r' && handshake ~= 'b'
                handshake = 'k';
            else
                fgetl(s);
            end
        end
        
        fwrite(s,'.RY070')
        %Wait for Arduino to be ready for next command
        handshake = 'k';
        while handshake == 'k'
            handshake = fgetl(s);
            if handshake ~='r' && handshake ~= 'b'
                handshake = 'k';
            else
                fgetl(s);
            end
        end
    end

    if axis == 'X'
        row = 1; %Populate rows 1,2 for X axis
        
		%Move y servos to center of range
        if side == 'L'
            fwrite(s,'.LY075');
        else
            fwrite(s,'.RY070');
        end
        
        %Wait for Arduino to be ready for next command
        handshake = 'k';
        while handshake == 'k'
            handshake = fgetl(s);
            if handshake ~='r' && handshake ~= 'b'
                handshake = 'k';
            else
                fgetl(s);
            end
        end
        
    else
        row =3; %Populate rows 3,4 for Y axis
        
		%move x axis servos to center of range
        if side == 'L'
            fwrite(s,'.LX074');
        else
            fwrite(s,'.RX080');
        end
        
        %Wait for Arduino to be ready for next command
        handshake = 'k';
        while handshake == 'k'
            handshake = fgetl(s);
            if handshake ~='r' && handshake ~= 'b'
                handshake = 'k';
            else
                fgetl(s);
            end
        end
    end
        
    if mode == 'P'
        %Set start and end angles for each direction in perimeter mode
        if direction == 'N'
            if side == 'R'
                start = 80;
                finish = 3;
            end
            if side == 'L'
                start = 74;
                finish = 3;
            end
            row = row+1;
            dir = -1;
        else
           if side == 'R'
                start = 80;
                finish = 177;
            end
            if side == 'L'
                start = 74;
                finish = 177;
            end
            dir = 1;
        end
		%Perform scan
        angle = MotorMove( side,axis,s,start,finish,dir,statusBox );
		
		%Update table with returned angle
        angleData(row,col) = angle;
        set(table1,'data',angleData)
        drawnow
        
    elseif mode == 'B'
		%For Y axis, scan through center of located blind spot in X
        if axis == 'Y'
            R_X = num2str((blindSpotData(1,col) + blindSpotData(2,col))/2);
            
            if length(R_X) == 1
                R_X = ['00' R_X];
            elseif length(R_X) == 2
                R_X = ['0' R_X];
            end
            
            fwrite(s,['.' side 'X' R_X]);
            
            %Wait for Arduino to be ready for next command
            handshake = 'k';
            while handshake == 'k'
                handshake = fgetl(s);
                if handshake ~='r' && handshake ~= 'b'
                    handshake = 'k';
                else
                    fgetl(s);
                end
            end
        end
		
		%Set start and end angles for each direction in perimeter mode
        if direction == 'P'
            if axis == 'X'
                start = 60;
                finish = 177;
            else
                start = 35;
                finish = 177;
            end
            dir = 1;
        else
             if axis == 'X'
                 start = 150;
                finish = 60;
             else
                 start = 105;
                finish = 3;
             end
            dir = -1;
            row = row+1;
        end
        
		%Perform scan
        angle =  MotorMove( side,axis,s,start,finish,dir,statusBox );
        blindSpotData(row,col) = angle;
		%Update table with returned angle
        set(table2,'data',blindSpotData)
        drawnow
        
    else
	%Mode not selected
        errordlg('Please Select a Mode')
    end
end
